==> kubernetes-model-core-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/AzureDiskVolumeSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class AzureDiskVolumeSourceBuilder extends AzureDiskVolumeSourceFluentImpl<AzureDiskVolumeSourceBuilder> implements VisitableBuilder<AzureDiskVolumeSource,AzureDiskVolumeSourceBuilder>{
  public AzureDiskVolumeSourceBuilder() {
    this(false);
  }
  public AzureDiskVolumeSourceBuilder(Boolean validationEnabled) {
    this(new AzureDiskVolumeSource(), validationEnabled);
  }
  public AzureDiskVolumeSourceBuilder(AzureDiskVolumeSourceFluent<?> fluent) {
    this(fluent, false);
  }
  public AzureDiskVolumeSourceBuilder(AzureDiskVolumeSourceFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new AzureDiskVolumeSource(), validationEnabled);
  }
  public AzureDiskVolumeSourceBuilder(AzureDiskVolumeSourceFluent<?> fluent,AzureDiskVolumeSource instance) {
    this(fluent, instance, false);
  }
  public AzureDiskVolumeSourceBuilder(AzureDiskVolumeSourceFluent<?> fluent,AzureDiskVolumeSource instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withCachingMode(instance.getCachingMode());
      fluent.withDiskName(instance.getDiskName());
      fluent.withDiskURI(instance.getDiskURI());
      fluent.withFsType(instance.getFsType());
      fluent.withKind(instance.getKind());
      fluent.withReadOnly(instance.getReadOnly());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public AzureDiskVolumeSourceBuilder(AzureDiskVolumeSource instance) {
    this(instance,false);
  }
  public AzureDiskVolumeSourceBuilder(AzureDiskVolumeSource instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withCachingMode(instance.getCachingMode());
      this.withDiskName(instance.getDiskName());
      this.withDiskURI(instance.getDiskURI());
      this.withFsType(instance.getFsType());
      this.withKind(instance.getKind());
      this.withReadOnly(instance.getReadOnly());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  AzureDiskVolumeSourceFluent<?> fluent;
  Boolean validationEnabled;
  public AzureDiskVolumeSource build() {
    AzureDiskVolumeSource buildable = new AzureDiskVolumeSource(fluent.getCachingMode(),fluent.getDiskName(),fluent.getDiskURI(),fluent.getFsType(),fluent.getKind(),fluent.getReadOnly());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> kubernetes-model-core-6.8.1-sources.jar: io/fabric8/kubernetes/api/model/AzureDiskVolumeSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class AzureDiskVolumeSourceBuilder extends AzureDiskVolumeSourceFluent<AzureDiskVolumeSourceBuilder> implements VisitableBuilder<AzureDiskVolumeSource,AzureDiskVolumeSourceBuilder>{
  public AzureDiskVolumeSourceBuilder() {
    this(false);
  }
  public AzureDiskVolumeSourceBuilder(Boolean validationEnabled) {
    this(new AzureDiskVolumeSource(), validationEnabled);
  }
  public AzureDiskVolumeSourceBuilder(AzureDiskVolumeSourceFluent<?> fluent) {
    this(fluent, false);
  }
  public AzureDiskVolumeSourceBuilder(AzureDiskVolumeSourceFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new AzureDiskVolumeSource(), validationEnabled);
  }
  public AzureDiskVolumeSourceBuilder(AzureDiskVolumeSourceFluent<?> fluent,AzureDiskVolumeSource instance) {
    this(fluent, instance, false);
  }
  public AzureDiskVolumeSourceBuilder(AzureDiskVolumeSourceFluent<?> fluent,AzureDiskVolumeSource instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new AzureDiskVolumeSource());

    if (instance != null) {
      fluent.withCachingMode(instance.getCachingMode());
      fluent.withDiskName(instance.getDiskName());
      fluent.withDiskURI(instance.getDiskURI());
      fluent.withFsType(instance.getFsType());
      fluent.withKind(instance.getKind());
      fluent.withReadOnly(instance.getReadOnly());
      fluent.withCachingMode(instance.getCachingMode());
      fluent.withDiskName(instance.getDiskName());
      fluent.withDiskURI(instance.getDiskURI());
      fluent.withFsType(instance.getFsType());
      fluent.withKind(instance.getKind());
      fluent.withReadOnly(instance.getReadOnly());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public AzureDiskVolumeSourceBuilder(AzureDiskVolumeSource instance) {
    this(instance,false);
  }
  public AzureDiskVolumeSourceBuilder(AzureDiskVolumeSource instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new AzureDiskVolumeSource());

    if (instance != null) {
      this.withCachingMode(instance.getCachingMode());
      this.withDiskName(instance.getDiskName());
      this.withDiskURI(instance.getDiskURI());
      this.withFsType(instance.getFsType());
      this.withKind(instance.getKind());
      this.withReadOnly(instance.getReadOnly());
      this.withCachingMode(instance.getCachingMode());
      this.withDiskName(instance.getDiskName());
      this.withDiskURI(instance.getDiskURI());
      this.withFsType(instance.getFsType());
      this.withKind(instance.getKind());
      this.withReadOnly(instance.getReadOnly());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  AzureDiskVolumeSourceFluent<?> fluent;
  Boolean validationEnabled;
  public AzureDiskVolumeSource build() {
    AzureDiskVolumeSource buildable = new AzureDiskVolumeSource(fluent.getCachingMode(),fluent.getDiskName(),fluent.getDiskURI(),fluent.getFsType(),fluent.getKind(),fluent.getReadOnly());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
